EmbFft

Struct EmbFft 

pub struct EmbFft<'a, T, const N: usize> { /* private fields */ }
Decimation in frequency fast Fourier transform

This structure contains a reference to the input / output data, as well as information related to the internal state.

Implementations

Source

impl<'a, T: Float<N>, const N: usize> EmbFft<'a, T, N>

pub fn new(data: &'a mut [(T, T); N]) -> Self

Initializes a new FFT conversion

Use this function whenever a new conversion is required.

pub fn fft_iterate(&mut self)

Non-blocking FFT computation

Use this together with the EmbFft::is_done() function. For example:

let mut data = [
    (1.0f32, 1.0), (2.0, 2.0),
    (3.0f32, 3.0), (4.0, 4.0),
    (5.0f32, 5.0), (6.0, 6.0),
    (7.0f32, 7.0), (8.0, 8.0)
];

let mut fft = embfft::EmbFft::new(&mut data);
while !fft.is_done() {
    fft.fft_iterate();
    // Other actions can be performed here between two iterations
}
pub fn fft(&mut self)

Blocking FFT computation

For example:

let mut data = [
    (1.0f32, 1.0), (2.0, 2.0),
    (3.0f32, 3.0), (4.0, 4.0),
    (5.0f32, 5.0), (6.0, 6.0),
    (7.0f32, 7.0), (8.0, 8.0)
];
embfft::EmbFft::new(&mut data).fft();
pub fn is_done(&self) -> bool

Checks if the conversion is complete

Use this together with the EmbFft::fft_iterate() function.